# Scarecrow v0.0.1
Low code web development for data science

## Introduction
Existing web development platforms don't offer what the data science community needs:
* Python-based frameworks like Flask and Django require additional learning: even if you understand Python and its ecosystem, you still need to learn more about HTML, CSS, HTTP requests, and routing infrastructure.
* All-python alternatives like Streamlit offer limited personalisation and limited support for infrstructure like multiple pages, user authentication, and session tracking.
Scarecrow offers a fully customisationbale framework for building data science apps, which works out of the box and will be free forever.

## Team
Scarecrow was established by Michael Hayman, who is fully responsible for its development and maintenance. If you would like to contribute to Scarecrow, please email mdghayman@gmail.com to share your proposal and your background.
